@@ -1,7 +1,6 @@
-def execute_code(run_result, current_file, save_function, exec_manager):
+def execute_code(current_file, save_function, exec_manager):
     """
     :param exec_manager:
-    :param run_result tkinter textarea to show result
     :param current_file will execute file
     :param save_function if current_file is None or "" save and run
     """
@@ -11,3 +10,7 @@ def execute_code(run_result, current_file, save_function, exec_manager):
         save_function()
         if current_file is not None and current_file != "":
             exec_manager.exec_code(current_file)
+
+
+def stop_program(exec_manager):
+    exec_manager.exit_program()
